# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from ai.stigmer.iam.iampolicy.v1 import spec_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_spec__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/iam/iampolicy/v1/command.proto\x12\x1b\x61i.stigmer.iam.iampolicy.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a%ai/stigmer/iam/iampolicy/v1/api.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a&ai/stigmer/iam/iampolicy/v1/spec.proto\x1a\x1bgoogle/protobuf/empty.proto2\xb9\x05\n\x1aIamPolicyCommandController\x12\x82\x01\n\x06\x63reate\x12*.ai.stigmer.iam.iampolicy.v1.IamPolicySpec\x1a&.ai.stigmer.iam.iampolicy.v1.IamPolicy\"$\xc2\xb8\x18 \x08\x08*\x1cunauthorized to grant access\x12\x83\x01\n\x06\x64\x65lete\x12*.ai.stigmer.iam.iampolicy.v1.IamPolicySpec\x1a&.ai.stigmer.iam.iampolicy.v1.IamPolicy\"%\xc2\xb8\x18!\x08\x08*\x1dunauthorized to revoke access\x12\xc2\x01\n\x0f\x62ootstrapPolicy\x12*.ai.stigmer.iam.iampolicy.v1.IamPolicySpec\x1a&.ai.stigmer.iam.iampolicy.v1.IamPolicy\"[\xc2\xb8\x18W\x08\x1d\x10\x1f*Hunauthorized to bootstrap policy - can_bootstrap_iam permission required2\x07stigmer\x12\xc4\x01\n\x17\x63leanupResourcePolicies\x12+.ai.stigmer.iam.iampolicy.v1.ApiResourceRef\x1a\x16.google.protobuf.Empty\"d\xc2\xb8\x18`\x08\x1d\x10\x1f*Qunauthorized to cleanup resource policies - can_bootstrap_iam permission required2\x07stigmer\x1a\x04\xa0\xff+\nB\xc0\x01\n\x1f\x63om.ai.stigmer.iam.iampolicy.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\x1b\x41i.Stigmer.Iam.Iampolicy.V1\xca\x02\x1b\x41i\\Stigmer\\Iam\\Iampolicy\\V1\xe2\x02\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Iam::Iampolicy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.iam.iampolicy.v1B\014CommandProtoP\001\242\002\004ASII\252\002\033Ai.Stigmer.Iam.Iampolicy.V1\312\002\033Ai\\Stigmer\\Iam\\Iampolicy\\V1\342\002\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Iam::Iampolicy::V1'
  _globals['_IAMPOLICYCOMMANDCONTROLLER']._loaded_options = None
  _globals['_IAMPOLICYCOMMANDCONTROLLER']._serialized_options = b'\240\377+\n'
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030 \010\010*\034unauthorized to grant access'
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030!\010\010*\035unauthorized to revoke access'
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['bootstrapPolicy']._loaded_options = None
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['bootstrapPolicy']._serialized_options = b'\302\270\030W\010\035\020\037*Hunauthorized to bootstrap policy - can_bootstrap_iam permission required2\007stigmer'
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['cleanupResourcePolicies']._loaded_options = None
  _globals['_IAMPOLICYCOMMANDCONTROLLER'].methods_by_name['cleanupResourcePolicies']._serialized_options = b'\302\270\030`\010\035\020\037*Qunauthorized to cleanup resource policies - can_bootstrap_iam permission required2\007stigmer'
  _globals['_IAMPOLICYCOMMANDCONTROLLER']._serialized_start=308
  _globals['_IAMPOLICYCOMMANDCONTROLLER']._serialized_end=1005
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/session/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/session/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.session.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ai/stigmer/agentic/session/v1/io.proto\x12\x1d\x61i.stigmer.agentic.session.v1\x1a\'ai/stigmer/agentic/session/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\")\n\tSessionId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\'\n\x07\x41gentId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"p\n\x0bSessionList\x12\x1f\n\x0btotal_pages\x18\x01 \x01(\x05R\ntotalPages\x12@\n\x07\x65ntries\x18\x02 \x03(\x0b\x32&.ai.stigmer.agentic.session.v1.SessionR\x07\x65ntries\"e\n\x13ListSessionsRequest\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x02 \x01(\tR\tpageToken\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\"{\n\x1aListSessionsByAgentRequest\x12!\n\x08\x61gent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x61gentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"O\n\x1bUpdateSessionSubjectRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\"V\n\x1dUpdateSessionSandboxIdRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12\x1d\n\nsandbox_id\x18\x02 \x01(\tR\tsandboxIdB\xc5\x01\n!com.ai.stigmer.agentic.session.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1d\x41i.Stigmer.Agentic.Session.V1\xca\x02\x1d\x41i\\Stigmer\\Agentic\\Session\\V1\xe2\x02)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\xea\x02!Ai::Stigmer::Agentic::Session::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.session.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.ai.stigmer.agentic.session.v1B\007IoProtoP\001\242\002\004ASAS\252\002\035Ai.Stigmer.Agentic.Session.V1\312\002\035Ai\\Stigmer\\Agentic\\Session\\V1\342\002)Ai\\Stigmer\\Agentic\\Session\\V1\\GPBMetadata\352\002!Ai::Stigmer::Agentic::Session::V1'
  _globals['_SESSIONID'].fields_by_name['value']._loaded_options = None
  _globals['_SESSIONID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENTID'].fields_by_name['value']._loaded_options = None
  _globals['_AGENTID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTSESSIONSBYAGENTREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_LISTSESSIONSBYAGENTREQUEST'].fields_by_name['agent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATESESSIONSUBJECTREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATESESSIONSUBJECTREQUEST'].fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_UPDATESESSIONSANDBOXIDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATESESSIONSANDBOXIDREQUEST'].fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_SESSIONID']._serialized_start=143
  _globals['_SESSIONID']._serialized_end=184
  _globals['_AGENTID']._serialized_start=186
  _globals['_AGENTID']._serialized_end=225
  _globals['_SESSIONLIST']._serialized_start=227
  _globals['_SESSIONLIST']._serialized_end=339
  _globals['_LISTSESSIONSREQUEST']._serialized_start=341
  _globals['_LISTSESSIONSREQUEST']._serialized_end=442
  _globals['_LISTSESSIONSBYAGENTREQUEST']._serialized_start=444
  _globals['_LISTSESSIONSBYAGENTREQUEST']._serialized_end=567
  _globals['_UPDATESESSIONSUBJECTREQUEST']._serialized_start=569
  _globals['_UPDATESESSIONSUBJECTREQUEST']._serialized_end=648
  _globals['_UPDATESESSIONSANDBOXIDREQUEST']._serialized_start=650
  _globals['_UPDATESESSIONSANDBOXIDREQUEST']._serialized_end=736
# @@protoc_insertion_point(module_scope)



from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GrpcCallTaskConfig(_message.Message):
    __slots__ = ("service", "method", "request")
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    service: str
    method: str
    request: _struct_pb2.Struct
    def __init__(self, service: _Optional[str] = ..., method: _Optional[str] = ..., request: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.skill.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2
from ai.stigmer.agentic.skill.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class SkillQueryControllerStub(object):
    """SkillQueryController handles read operations for skills.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillQueryController/get',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)
        self.getByReference = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillQueryController/getByReference',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
                _registered_method=True)
        self.getArtifact = channel.unary_unary(
                '/ai.stigmer.agentic.skill.v1.SkillQueryController/getArtifact',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactResponse.FromString,
                _registered_method=True)


class SkillQueryControllerServicer(object):
    """SkillQueryController handles read operations for skills.
    """

    def get(self, request, context):
        """Get a single skill by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getByReference(self, request, context):
        """Get a skill by API resource reference with version support.

        Version resolution (via ApiResourceReference.version field):
        - Empty/"latest" → Returns current version from main collection
        - Tag name (e.g., "stable", "v1.0") → Resolves to version with this tag
        - SHA256 hash (64 hex chars) → Returns exact immutable version

        Authorization is handled in the handler after resolving the reference to a skill ID.
        (Input doesn't contain skill ID, so proto-level auth cannot work)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getArtifact(self, request, context):
        """Download skill artifact from storage by its storage key.
        Returns the ZIP file containing SKILL.md and implementation files.

        This endpoint is used by the agent-runner to download and extract
        skill artifacts into the sandbox at /bin/skills/{version_hash}/.

        Authorization is skipped as the storage key itself acts as a capability token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SkillQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
            'getByReference': grpc.unary_unary_rpc_method_handler(
                    servicer.getByReference,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.SerializeToString,
            ),
            'getArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.getArtifact,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.skill.v1.SkillQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.skill.v1.SkillQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SkillQueryController(object):
    """SkillQueryController handles read operations for skills.
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillQueryController/get',
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.SkillId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getByReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillQueryController/getByReference',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2.Skill.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.skill.v1.SkillQueryController/getArtifact',
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2.GetArtifactResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityprovider/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityprovider/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ai/stigmer/iam/identityprovider/v1/spec.proto\x12\"ai.stigmer.iam.identityprovider.v1\x1a\x1b\x62uf/validate/validate.proto\"\xab\x02\n\x14IdentityProviderSpec\x12+\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01R\x0b\x64isplayName\x12#\n\x08jwks_uri\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x10R\x07jwksUri\x12\'\n\x0f\x61llowed_issuers\x18\x03 \x03(\tR\x0e\x61llowedIssuers\x12\x35\n\x11\x65xpected_audience\x18\x04 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01R\x10\x65xpectedAudience\x12*\n\x11rate_limit_budget\x18\x05 \x01(\x05R\x0frateLimitBudget\x12\x35\n\x11userinfo_endpoint\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\x80\x10R\x10userinfoEndpointB\xe0\x01\n&com.ai.stigmer.iam.identityprovider.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\"Ai.Stigmer.Iam.Identityprovider.V1\xca\x02\"Ai\\Stigmer\\Iam\\Identityprovider\\V1\xe2\x02.Ai\\Stigmer\\Iam\\Identityprovider\\V1\\GPBMetadata\xea\x02&Ai::Stigmer::Iam::Identityprovider::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityprovider.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.ai.stigmer.iam.identityprovider.v1B\tSpecProtoP\001\242\002\004ASII\252\002\"Ai.Stigmer.Iam.Identityprovider.V1\312\002\"Ai\\Stigmer\\Iam\\Identityprovider\\V1\342\002.Ai\\Stigmer\\Iam\\Identityprovider\\V1\\GPBMetadata\352\002&Ai::Stigmer::Iam::Identityprovider::V1'
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['display_name']._loaded_options = None
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['display_name']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['jwks_uri']._loaded_options = None
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['jwks_uri']._serialized_options = b'\272H\005r\003\030\200\020'
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['expected_audience']._loaded_options = None
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['expected_audience']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['userinfo_endpoint']._loaded_options = None
  _globals['_IDENTITYPROVIDERSPEC'].fields_by_name['userinfo_endpoint']._serialized_options = b'\272H\005r\003\030\200\020'
  _globals['_IDENTITYPROVIDERSPEC']._serialized_start=115
  _globals['_IDENTITYPROVIDERSPEC']._serialized_end=414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ai/stigmer/iam/apikey/v1/io.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\"ai/stigmer/iam/apikey/v1/api.proto\x1a\x1b\x62uf/validate/validate.proto\"E\n\x07\x41piKeys\x12:\n\x07\x65ntries\x18\x01 \x03(\x0b\x32 .ai.stigmer.iam.apikey.v1.ApiKeyR\x07\x65ntries\"(\n\x08\x41piKeyId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"*\n\nApiKeyHash\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05valueB\xac\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\007IoProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYID'].fields_by_name['value']._loaded_options = None
  _globals['_APIKEYID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYHASH'].fields_by_name['value']._loaded_options = None
  _globals['_APIKEYHASH'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYS']._serialized_start=128
  _globals['_APIKEYS']._serialized_end=197
  _globals['_APIKEYID']._serialized_start=199
  _globals['_APIKEYID']._serialized_end=239
  _globals['_APIKEYHASH']._serialized_start=241
  _globals['_APIKEYHASH']._serialized_end=283
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as _spec_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowExecutionSpec(_message.Message):
    __slots__ = ("workflow_instance_id", "workflow_id", "trigger_message", "trigger_metadata", "runtime_env", "callback_token")
    class TriggerMetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class RuntimeEnvEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _spec_pb2.ExecutionValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_spec_pb2.ExecutionValue, _Mapping]] = ...) -> None: ...
    WORKFLOW_INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_METADATA_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ENV_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_TOKEN_FIELD_NUMBER: _ClassVar[int]
    workflow_instance_id: str
    workflow_id: str
    trigger_message: str
    trigger_metadata: _containers.ScalarMap[str, str]
    runtime_env: _containers.MessageMap[str, _spec_pb2.ExecutionValue]
    callback_token: bytes
    def __init__(self, workflow_instance_id: _Optional[str] = ..., workflow_id: _Optional[str] = ..., trigger_message: _Optional[str] = ..., trigger_metadata: _Optional[_Mapping[str, str]] = ..., runtime_env: _Optional[_Mapping[str, _spec_pb2.ExecutionValue]] = ..., callback_token: _Optional[bytes] = ...) -> None: ...



from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from ai.stigmer.commons.apiresource import enum_pb2 as _enum_pb2
from ai.stigmer.commons.rpc import pagination_pb2 as _pagination_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class ApiResourceDeleteInput(_message.Message):
    __slots__ = ("resource_id", "version_message", "force")
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    FORCE_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    version_message: str
    force: bool
    def __init__(self, resource_id: _Optional[str] = ..., version_message: _Optional[str] = ..., force: bool = ...) -> None: ...

class ApiResourceByOrgBySlugRequest(_message.Message):
    __slots__ = ("org", "slug")
    ORG_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    org: str
    slug: str
    def __init__(self, org: _Optional[str] = ..., slug: _Optional[str] = ...) -> None: ...

class FindApiResourcesRequest(_message.Message):
    __slots__ = ("org", "kind", "page", "page_number", "page_size")
    ORG_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    org: str
    kind: str
    page: _pagination_pb2.PageInfo
    page_number: int
    page_size: int
    def __init__(self, org: _Optional[str] = ..., kind: _Optional[str] = ..., page: _Optional[_Union[_pagination_pb2.PageInfo, _Mapping]] = ..., page_number: _Optional[int] = ..., page_size: _Optional[int] = ...) -> None: ...

class UpdateVisibilityInput(_message.Message):
    __slots__ = ("resource_id", "visibility")
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    visibility: _enum_pb2.ApiResourceVisibility
    def __init__(self, resource_id: _Optional[str] = ..., visibility: _Optional[_Union[_enum_pb2.ApiResourceVisibility, str]] = ...) -> None: ...

class ApiResourceReference(_message.Message):
    __slots__ = ("org", "kind", "slug", "version")
    ORG_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    org: str
    kind: _api_resource_kind_pb2.ApiResourceKind
    slug: str
    version: str
    def __init__(self, org: _Optional[str] = ..., kind: _Optional[_Union[_api_resource_kind_pb2.ApiResourceKind, str]] = ..., slug: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ValidationState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VALIDATION_STATE_UNSPECIFIED: _ClassVar[ValidationState]
    PENDING: _ClassVar[ValidationState]
    VALID: _ClassVar[ValidationState]
    INVALID: _ClassVar[ValidationState]
    FAILED: _ClassVar[ValidationState]
VALIDATION_STATE_UNSPECIFIED: ValidationState
PENDING: ValidationState
VALID: ValidationState
INVALID: ValidationState
FAILED: ValidationState

class ServerlessWorkflowValidation(_message.Message):
    __slots__ = ("state", "yaml", "errors", "warnings", "validated_at", "validation_workflow_id")
    STATE_FIELD_NUMBER: _ClassVar[int]
    YAML_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    WARNINGS_FIELD_NUMBER: _ClassVar[int]
    VALIDATED_AT_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    state: ValidationState
    yaml: str
    errors: _containers.RepeatedScalarFieldContainer[str]
    warnings: _containers.RepeatedScalarFieldContainer[str]
    validated_at: _timestamp_pb2.Timestamp
    validation_workflow_id: str
    def __init__(self, state: _Optional[_Union[ValidationState, str]] = ..., yaml: _Optional[str] = ..., errors: _Optional[_Iterable[str]] = ..., warnings: _Optional[_Iterable[str]] = ..., validated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., validation_workflow_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/rpc_service_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/rpc_service_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ai/stigmer/commons/apiresource/rpc_service_options.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a google/protobuf/descriptor.proto:\x8e\x01\n\x11\x61pi_resource_kind\x12\x1f.google.protobuf.ServiceOptions\x18\xf4\xbf\x05 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x0f\x61piResourceKindB\xd8\x01\n\"com.ai.stigmer.commons.apiresourceB\x16RpcServiceOptionsProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.rpc_service_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\026RpcServiceOptionsProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/identityaccount/v1/enum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/identityaccount/v1/enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/iam/identityaccount/v1/enum.proto\x12!ai.stigmer.iam.identityaccount.v1*}\n\x1fIdentityAccountProvisioningMode\x12\x32\n.identity_account_provisioning_mode_unspecified\x10\x00\x12\n\n\x06\x64irect\x10\x01\x12\r\n\tfederated\x10\x02\x12\x0b\n\x07machine\x10\x03\x42\xdb\x01\n%com.ai.stigmer.iam.identityaccount.v1B\tEnumProtoP\x01\xa2\x02\x04\x41SII\xaa\x02!Ai.Stigmer.Iam.Identityaccount.V1\xca\x02!Ai\\Stigmer\\Iam\\Identityaccount\\V1\xe2\x02-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\xea\x02%Ai::Stigmer::Iam::Identityaccount::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.identityaccount.v1.enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%com.ai.stigmer.iam.identityaccount.v1B\tEnumProtoP\001\242\002\004ASII\252\002!Ai.Stigmer.Iam.Identityaccount.V1\312\002!Ai\\Stigmer\\Iam\\Identityaccount\\V1\342\002-Ai\\Stigmer\\Iam\\Identityaccount\\V1\\GPBMetadata\352\002%Ai::Stigmer::Iam::Identityaccount::V1'
  _globals['_IDENTITYACCOUNTPROVISIONINGMODE']._serialized_start=83
  _globals['_IDENTITYACCOUNTPROVISIONINGMODE']._serialized_end=208
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.session.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2
from ai.stigmer.agentic.session.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2


class SessionQueryControllerStub(object):
    """SessionQueryController handles read operations for agent sessions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionQueryController/get',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionQueryController/list',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.FromString,
                _registered_method=True)
        self.listByAgent = channel.unary_unary(
                '/ai.stigmer.agentic.session.v1.SessionQueryController/listByAgent',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsByAgentRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.FromString,
                _registered_method=True)


class SessionQueryControllerServicer(object):
    """SessionQueryController handles read operations for agent sessions.
    """

    def get(self, request, context):
        """Get a single session by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """List all sessions with pagination and optional filtering.
        Authorization is handled in-handler via FGA-filtered queries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listByAgent(self, request, context):
        """List all sessions for a specific agent.
        Authorization is handled in-handler via FGA-filtered queries.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.SerializeToString,
            ),
            'listByAgent': grpc.unary_unary_rpc_method_handler(
                    servicer.listByAgent,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsByAgentRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.session.v1.SessionQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.session.v1.SessionQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SessionQueryController(object):
    """SessionQueryController handles read operations for agent sessions.
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionQueryController/get',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_api__pb2.Session.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionQueryController/list',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def listByAgent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.session.v1.SessionQueryController/listByAgent',
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.ListSessionsByAgentRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_session_dot_v1_dot_io__pb2.SessionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as _api_resource_kind_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
COMPUTED_FIELD_NUMBER: _ClassVar[int]
computed: _descriptor.FieldDescriptor
IMMUTABLE_FIELD_NUMBER: _ClassVar[int]
immutable: _descriptor.FieldDescriptor
IS_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
is_expression: _descriptor.FieldDescriptor
REFERENCE_KIND_FIELD_NUMBER: _ClassVar[int]
reference_kind: _descriptor.FieldDescriptor
DISCRIMINATED_BY_FIELD_NUMBER: _ClassVar[int]
discriminated_by: _descriptor.FieldDescriptor
DISCRIMINATOR_VALUE_FIELD_NUMBER: _ClassVar[int]
discriminator_value: _descriptor.FieldDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/commons/apiresource/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/commons/apiresource/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ai/stigmer/commons/apiresource/status.proto\x12\x1e\x61i.stigmer.commons.apiresource\x1a\x1fgoogle/protobuf/timestamp.proto\"`\n\x16\x41piResourceAuditStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\"\xc0\x01\n\x10\x41piResourceAudit\x12S\n\nspec_audit\x18\x01 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceAuditInfoR\tspecAudit\x12W\n\x0cstatus_audit\x18\x02 \x01(\x0b\x32\x34.ai.stigmer.commons.apiresource.ApiResourceAuditInfoR\x0bstatusAudit\"\xce\x02\n\x14\x41piResourceAuditInfo\x12T\n\ncreated_by\x18\x01 \x01(\x0b\x32\x35.ai.stigmer.commons.apiresource.ApiResourceAuditActorR\tcreatedBy\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12T\n\nupdated_by\x18\x03 \x01(\x0b\x32\x35.ai.stigmer.commons.apiresource.ApiResourceAuditActorR\tupdatedBy\x12\x39\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x14\n\x05\x65vent\x18\x05 \x01(\tR\x05\x65vent\"?\n\x15\x41piResourceAuditActor\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06\x61vatar\x18\x02 \x01(\tR\x06\x61vatarB\xcd\x01\n\"com.ai.stigmer.commons.apiresourceB\x0bStatusProtoP\x01\xa2\x02\x04\x41SCA\xaa\x02\x1e\x41i.Stigmer.Commons.Apiresource\xca\x02\x1e\x41i\\Stigmer\\Commons\\Apiresource\xe2\x02*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\xea\x02!Ai::Stigmer::Commons::Apiresourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.commons.apiresource.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.commons.apiresourceB\013StatusProtoP\001\242\002\004ASCA\252\002\036Ai.Stigmer.Commons.Apiresource\312\002\036Ai\\Stigmer\\Commons\\Apiresource\342\002*Ai\\Stigmer\\Commons\\Apiresource\\GPBMetadata\352\002!Ai::Stigmer::Commons::Apiresource'
  _globals['_APIRESOURCEAUDITSTATUS']._serialized_start=112
  _globals['_APIRESOURCEAUDITSTATUS']._serialized_end=208
  _globals['_APIRESOURCEAUDIT']._serialized_start=211
  _globals['_APIRESOURCEAUDIT']._serialized_end=403
  _globals['_APIRESOURCEAUDITINFO']._serialized_start=406
  _globals['_APIRESOURCEAUDITINFO']._serialized_end=740
  _globals['_APIRESOURCEAUDITACTOR']._serialized_start=742
  _globals['_APIRESOURCEAUDITACTOR']._serialized_end=805
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/apikey/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/apikey/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.apikey.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_api__pb2
from ai.stigmer.iam.apikey.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_apikey_dot_v1_dot_io__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ai/stigmer/iam/apikey/v1/query.proto\x12\x18\x61i.stigmer.iam.apikey.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\"ai/stigmer/iam/apikey/v1/api.proto\x1a!ai/stigmer/iam/apikey/v1/io.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto\x1a\x1bgoogle/protobuf/empty.proto2\xc3\x02\n\x15\x41piKeyQueryController\x12z\n\x03get\x12\".ai.stigmer.iam.apikey.v1.ApiKeyId\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"-\xc2\xb8\x18)\x08\x03\x10\x0c\"\x05value*\x1cunauthorized to view api key\x12\\\n\x0cgetByKeyHash\x12$.ai.stigmer.iam.apikey.v1.ApiKeyHash\x1a .ai.stigmer.iam.apikey.v1.ApiKey\"\x04\xd0\xb8\x18\x01\x12J\n\x07\x66indAll\x12\x16.google.protobuf.Empty\x1a!.ai.stigmer.iam.apikey.v1.ApiKeys\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+\x0c\x42\xaf\x01\n\x1c\x63om.ai.stigmer.iam.apikey.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SIA\xaa\x02\x18\x41i.Stigmer.Iam.Apikey.V1\xca\x02\x18\x41i\\Stigmer\\Iam\\Apikey\\V1\xe2\x02$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\xea\x02\x1c\x41i::Stigmer::Iam::Apikey::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.apikey.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ai.stigmer.iam.apikey.v1B\nQueryProtoP\001\242\002\004ASIA\252\002\030Ai.Stigmer.Iam.Apikey.V1\312\002\030Ai\\Stigmer\\Iam\\Apikey\\V1\342\002$Ai\\Stigmer\\Iam\\Apikey\\V1\\GPBMetadata\352\002\034Ai::Stigmer::Iam::Apikey::V1'
  _globals['_APIKEYQUERYCONTROLLER']._loaded_options = None
  _globals['_APIKEYQUERYCONTROLLER']._serialized_options = b'\240\377+\014'
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030)\010\003\020\014\"\005value*\034unauthorized to view api key'
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['getByKeyHash']._loaded_options = None
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['getByKeyHash']._serialized_options = b'\320\270\030\001'
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['findAll']._loaded_options = None
  _globals['_APIKEYQUERYCONTROLLER'].methods_by_name['findAll']._serialized_options = b'\320\270\030\001'
  _globals['_APIKEYQUERYCONTROLLER']._serialized_start=292
  _globals['_APIKEYQUERYCONTROLLER']._serialized_end=615
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PageInfo(_message.Message):
    __slots__ = ("num", "size")
    NUM_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    num: int
    size: int
    def __init__(self, num: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class GooglePageInfo(_message.Message):
    __slots__ = ("page_token", "size")
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    page_token: str
    size: int
    def __init__(self, page_token: _Optional[str] = ..., size: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_executioncontext_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/agentexecution/v1/spec.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a\x31\x61i/stigmer/agentic/executioncontext/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\"\xb8\x05\n\x12\x41gentExecutionSpec\x12\x1d\n\nsession_id\x18\x01 \x01(\tR\tsessionId\x12\x19\n\x08\x61gent_id\x18\x02 \x01(\tR\x07\x61gentId\x12!\n\x07message\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07message\x12`\n\x10\x65xecution_config\x18\x04 \x01(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.ExecutionConfigR\x0f\x65xecutionConfig\x12i\n\x0bruntime_env\x18\x05 \x03(\x0b\x32H.ai.stigmer.agentic.agentexecution.v1.AgentExecutionSpec.RuntimeEnvEntryR\nruntimeEnv\x12%\n\x0e\x63\x61llback_token\x18\x06 \x01(\x0cR\rcallbackToken\x12(\n\x10\x61uto_approve_all\x18\x07 \x01(\x08R\x0e\x61utoApproveAll\x12,\n\x12parent_workflow_id\x18\x08 \x01(\tR\x10parentWorkflowId\x12R\n\x0b\x61ttachments\x18\t \x03(\x0b\x32\x30.ai.stigmer.agentic.agentexecution.v1.AttachmentR\x0b\x61ttachments\x12.\n\x13workspace_file_refs\x18\n \x03(\tR\x11workspaceFileRefs\x1au\n\x0fRuntimeEnvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12L\n\x05value\x18\x02 \x01(\x0b\x32\x36.ai.stigmer.agentic.executioncontext.v1.ExecutionValueR\x05value:\x02\x38\x01\"\x9b\x02\n\x0f\x45xecutionConfig\x12\x1d\n\nmodel_name\x18\x01 \x01(\tR\tmodelName\x12l\n\x12\x63ontext_management\x18\x02 \x01(\x0b\x32=.ai.stigmer.agentic.agentexecution.v1.ContextManagementConfigR\x11\x63ontextManagement\x12&\n\x0fmax_tool_rounds\x18\x03 \x01(\x05R\rmaxToolRounds\x12\x31\n\x15max_tool_result_chars\x18\x04 \x01(\x05R\x12maxToolResultChars\x12 \n\x0cmax_cost_usd\x18\x05 \x01(\x01R\nmaxCostUsd\"\xcc\x01\n\x17\x43ontextManagementConfig\x12\x33\n\x15\x64isable_summarization\x18\x01 \x01(\x08R\x14\x64isableSummarization\x12\x41\n\x18\x63ustom_trigger_threshold\x18\x02 \x01(\x05\x42\x07\xbaH\x04\x1a\x02(\x00R\x16\x63ustomTriggerThreshold\x12\x39\n\x14\x63ustom_target_tokens\x18\x03 \x01(\x05\x42\x07\xbaH\x04\x1a\x02(\x00R\x12\x63ustomTargetTokens\"\xd6\x01\n\nAttachment\x12#\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08\x66ilename\x12(\n\x0bstorage_key\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\nstorageKey\x12\x1d\n\nmount_path\x18\x03 \x01(\tR\tmountPath\x12!\n\x0c\x63ontent_type\x18\x04 \x01(\tR\x0b\x63ontentType\x12\x18\n\x07\x65xtract\x18\x05 \x01(\x08R\x07\x65xtract\x12\x1d\n\nlocal_path\x18\x06 \x01(\tR\tlocalPathB\xea\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\tSpecProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._loaded_options = None
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_options = b'8\001'
  _globals['_AGENTEXECUTIONSPEC'].fields_by_name['message']._loaded_options = None
  _globals['_AGENTEXECUTIONSPEC'].fields_by_name['message']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_trigger_threshold']._loaded_options = None
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_trigger_threshold']._serialized_options = b'\272H\004\032\002(\000'
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_target_tokens']._loaded_options = None
  _globals['_CONTEXTMANAGEMENTCONFIG'].fields_by_name['custom_target_tokens']._serialized_options = b'\272H\004\032\002(\000'
  _globals['_ATTACHMENT'].fields_by_name['filename']._loaded_options = None
  _globals['_ATTACHMENT'].fields_by_name['filename']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ATTACHMENT'].fields_by_name['storage_key']._loaded_options = None
  _globals['_ATTACHMENT'].fields_by_name['storage_key']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTEXECUTIONSPEC']._serialized_start=170
  _globals['_AGENTEXECUTIONSPEC']._serialized_end=866
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_start=749
  _globals['_AGENTEXECUTIONSPEC_RUNTIMEENVENTRY']._serialized_end=866
  _globals['_EXECUTIONCONFIG']._serialized_start=869
  _globals['_EXECUTIONCONFIG']._serialized_end=1152
  _globals['_CONTEXTMANAGEMENTCONFIG']._serialized_start=1155
  _globals['_CONTEXTMANAGEMENTCONFIG']._serialized_end=1359
  _globals['_ATTACHMENT']._serialized_start=1362
  _globals['_ATTACHMENT']._serialized_end=1576
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/context.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_enum__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/agentexecution/v1/context.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a/ai/stigmer/agentic/agentexecution/v1/enum.proto\"\x89\x03\n\x18ResolvedExecutionContext\x12)\n\x10\x65nvironment_keys\x18\x01 \x03(\tR\x0f\x65nvironmentKeys\x12o\n\x0bmcp_servers\x18\x02 \x03(\x0b\x32N.ai.stigmer.agentic.agentexecution.v1.ResolvedExecutionContext.McpServersEntryR\nmcpServers\x12\x1f\n\x0bskill_names\x18\x03 \x03(\tR\nskillNames\x12\x30\n\x14\x65xcluded_skill_names\x18\x04 \x03(\tR\x12\x65xcludedSkillNames\x1a~\n\x0fMcpServersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12U\n\x05value\x18\x02 \x01(\x0b\x32?.ai.stigmer.agentic.agentexecution.v1.McpServerResolutionStatusR\x05value:\x02\x38\x01\"\x7f\n\x19McpServerResolutionStatus\x12\x1a\n\x08resolved\x18\x01 \x01(\x08R\x08resolved\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12,\n\x12\x65nabled_tool_count\x18\x03 \x01(\x05R\x10\x65nabledToolCount\"\xd0\x04\n\x12SummarizationEvent\x12\x1c\n\ttimestamp\x18\x01 \x01(\tR\ttimestamp\x12#\n\rtokens_before\x18\x02 \x01(\x05R\x0ctokensBefore\x12!\n\x0ctokens_after\x18\x03 \x01(\x05R\x0btokensAfter\x12+\n\x11\x63ompression_ratio\x18\x04 \x01(\x02R\x10\x63ompressionRatio\x12\x1f\n\x0b\x64uration_ms\x18\x05 \x01(\x05R\ndurationMs\x12/\n\x13summarization_model\x18\x06 \x01(\tR\x12summarizationModel\x12\'\n\x0fmessages_before\x18\x07 \x01(\x05R\x0emessagesBefore\x12%\n\x0emessages_after\x18\x08 \x01(\x05R\rmessagesAfter\x12Q\n\x06source\x18\t \x01(\x0e\x32\x39.ai.stigmer.agentic.agentexecution.v1.SummarizationSourceR\x06source\x12<\n\x1asummarization_input_tokens\x18\n \x01(\x05R\x18summarizationInputTokens\x12>\n\x1bsummarization_output_tokens\x18\x0b \x01(\x05R\x19summarizationOutputTokens\x12\x34\n\x16summarization_cost_usd\x18\x0c \x01(\x01R\x14summarizationCostUsd\"\xca\x03\n\x0b\x43ontextInfo\x12.\n\x13\x63urrent_token_count\x18\x01 \x01(\x05R\x11\x63urrentTokenCount\x12\x30\n\x14\x63ontext_window_limit\x18\x02 \x01(\x05R\x12\x63ontextWindowLimit\x12\x46\n\x1fsummarization_trigger_threshold\x18\x03 \x01(\x05R\x1dsummarizationTriggerThreshold\x12>\n\x1bsummarization_target_tokens\x18\x04 \x01(\x05R\x19summarizationTargetTokens\x12\x33\n\x15summarization_enabled\x18\x05 \x01(\x08R\x14summarizationEnabled\x12k\n\x14summarization_events\x18\x06 \x03(\x0b\x32\x38.ai.stigmer.agentic.agentexecution.v1.SummarizationEventR\x13summarizationEvents\x12/\n\x13utilization_percent\x18\x07 \x01(\x02R\x12utilizationPercentB\xed\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x0c\x43ontextProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\014ContextProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._loaded_options = None
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_options = b'8\001'
  _globals['_RESOLVEDEXECUTIONCONTEXT']._serialized_start=142
  _globals['_RESOLVEDEXECUTIONCONTEXT']._serialized_end=535
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_start=409
  _globals['_RESOLVEDEXECUTIONCONTEXT_MCPSERVERSENTRY']._serialized_end=535
  _globals['_MCPSERVERRESOLUTIONSTATUS']._serialized_start=537
  _globals['_MCPSERVERRESOLUTIONSTATUS']._serialized_end=664
  _globals['_SUMMARIZATIONEVENT']._serialized_start=667
  _globals['_SUMMARIZATIONEVENT']._serialized_end=1259
  _globals['_CONTEXTINFO']._serialized_start=1262
  _globals['_CONTEXTINFO']._serialized_end=1720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2ai/stigmer/agentic/workflowinstance/v1/query.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\x30\x61i/stigmer/agentic/workflowinstance/v1/api.proto\x1a/ai/stigmer/agentic/workflowinstance/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\x8b\x04\n\x1fWorkflowInstanceQueryController\x12\xb3\x01\n\x03get\x12:.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceId\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"6\xc2\xb8\x18\x32\x08\x03\x10\x33\"\x05value*%unauthorized to get workflow instance\x12\xa2\x01\n\rgetByWorkflow\x12M.ai.stigmer.agentic.workflowinstance.v1.GetWorkflowInstancesByWorkflowRequest\x1a<.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceList\"\x04\xd0\xb8\x18\x01\x12\x86\x01\n\x0egetByReference\x12\x34.ai.stigmer.commons.apiresource.ApiResourceReference\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+3B\xf5\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\nQueryProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_options = b'\240\377+3'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0302\010\003\0203\"\005value*%unauthorized to get workflow instance'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByWorkflow']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByWorkflow']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._loaded_options = None
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_start=360
  _globals['_WORKFLOWINSTANCEQUERYCONTROLLER']._serialized_end=883
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/search/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/search/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_apiresourcekind_dot_api__resource__kind__pb2
from ai.stigmer.commons.apiresource import enum_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_enum__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61i/stigmer/search/v1/io.proto\x12\x14\x61i.stigmer.search.v1\x1a\x46\x61i/stigmer/commons/apiresource/apiresourcekind/api_resource_kind.proto\x1a)ai/stigmer/commons/apiresource/enum.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x02\n\rSearchRequest\x12\x64\n\x05kinds\x18\x01 \x03(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x05kinds\x12\x1e\n\x05query\x18\x02 \x01(\tB\x08\xbaH\x05r\x03\x18\xf4\x03R\x05query\x12/\n\x03org\x18\x03 \x01(\tB\x1d\xbaH\x1ar\x18\x18?2\x14^$|^[a-z][a-z0-9-]*$R\x03org\x12%\n\x0e\x65xclude_public\x18\x04 \x01(\x08R\rexcludePublic\x12\x34\n\x04page\x18\x05 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x04page\"\xaf\x02\n\x0eSearchResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\".ai.stigmer.search.v1.SearchResultR\x07\x65ntries\x12\\\n\x0e\x63ounts_by_kind\x18\x02 \x03(\x0b\x32\x36.ai.stigmer.search.v1.SearchResponse.CountsByKindEntryR\x0c\x63ountsByKind\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\x12\x1f\n\x0btotal_pages\x18\x04 \x01(\x05R\ntotalPages\x1a?\n\x11\x43ountsByKindEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"\xed\x03\n\x0cSearchResult\x12S\n\x04kind\x18\x01 \x01(\x0e\x32?.ai.stigmer.commons.apiresource.apiresourcekind.ApiResourceKindR\x04kind\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x12\n\x04slug\x18\x04 \x01(\tR\x04slug\x12%\n\x0equalified_slug\x18\x05 \x01(\tR\rqualifiedSlug\x12\x10\n\x03org\x18\x06 \x01(\tR\x03org\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12U\n\nvisibility\x18\x08 \x01(\x0e\x32\x35.ai.stigmer.commons.apiresource.ApiResourceVisibilityR\nvisibility\x12\x12\n\x04tags\x18\t \x03(\tR\x04tags\x12\x39\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x14\n\x05score\x18\x0c \x01(\x02R\x05scoreB\x96\x01\n\x18\x63om.ai.stigmer.search.v1B\x07IoProtoP\x01\xa2\x02\x03\x41SS\xaa\x02\x14\x41i.Stigmer.Search.V1\xca\x02\x14\x41i\\Stigmer\\Search\\V1\xe2\x02 Ai\\Stigmer\\Search\\V1\\GPBMetadata\xea\x02\x17\x41i::Stigmer::Search::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.search.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.ai.stigmer.search.v1B\007IoProtoP\001\242\002\003ASS\252\002\024Ai.Stigmer.Search.V1\312\002\024Ai\\Stigmer\\Search\\V1\342\002 Ai\\Stigmer\\Search\\V1\\GPBMetadata\352\002\027Ai::Stigmer::Search::V1'
  _globals['_SEARCHREQUEST'].fields_by_name['kinds']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['kinds']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_SEARCHREQUEST'].fields_by_name['query']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['query']._serialized_options = b'\272H\005r\003\030\364\003'
  _globals['_SEARCHREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_SEARCHREQUEST'].fields_by_name['org']._serialized_options = b'\272H\032r\030\030?2\024^$|^[a-z][a-z0-9-]*$'
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._loaded_options = None
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHREQUEST']._serialized_start=274
  _globals['_SEARCHREQUEST']._serialized_end=565
  _globals['_SEARCHRESPONSE']._serialized_start=568
  _globals['_SEARCHRESPONSE']._serialized_end=871
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_start=808
  _globals['_SEARCHRESPONSE_COUNTSBYKINDENTRY']._serialized_end=871
  _globals['_SEARCHRESULT']._serialized_start=874
  _globals['_SEARCHRESULT']._serialized_end=1367
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.iam.iampolicy.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2
from ai.stigmer.iam.iampolicy.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2


class IamPolicyQueryControllerStub(object):
    """iam-policy query controller
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/get',
                request_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.IamPolicyId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2.IamPolicy.FromString,
                _registered_method=True)
        self.checkAuthorization = channel.unary_unary(
                '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/checkAuthorization',
                request_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationResult.FromString,
                _registered_method=True)
        self.listAuthorizedResourceIds = channel.unary_unary(
                '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/listAuthorizedResourceIds',
                request_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedResourceIdsInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedResourceIdsList.FromString,
                _registered_method=True)
        self.listAuthorizedPrincipalIds = channel.unary_unary(
                '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/listAuthorizedPrincipalIds',
                request_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedPrincipalIdsInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedPrincipalIdsList.FromString,
                _registered_method=True)


class IamPolicyQueryControllerServicer(object):
    """iam-policy query controller
    """

    def get(self, request, context):
        """lookup iam-policy by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def checkAuthorization(self, request, context):
        """Check if a principal is authorized to perform a relation on a resource

        This is the fundamental authorization check RPC that answers the question:
        "Does principal X have permission Y on resource Z?"

        It provides a simple boolean answer based on the complete authorization state,
        including existing IAM policies, inherited permissions, and group memberships.

        Use Cases:
        - Pre-flight UI checks before showing buttons/actions
        - API request authorization before processing operations
        - Service-to-service authorization
        - Team-based access checks

        Input: CheckAuthorizationInput with policy spec and optional contextual policies
        Output: CheckAuthorizationResult with is_authorized boolean
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listAuthorizedResourceIds(self, request, context):
        """List all resource IDs of a specific kind that a principal is authorized to access

        This RPC answers: "What are all the [resource-kind] that [principal] can [relation] on?"
        Essential for building permission-aware UIs and filtering resource lists.

        Use Cases:
        - Resource list filtering in dropdowns
        - Permission-based navigation
        - Bulk authorization checks

        Input: ListAuthorizedResourceIdsInput with principal, resource_kind, and relation
        Output: AuthorizedResourceIdsList containing all accessible resource IDs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listAuthorizedPrincipalIds(self, request, context):
        """List all principal IDs of a specific kind that are authorized to access a resource

        This RPC answers: "What are all the [principal-kind] that have [relation] access on [resource]?"
        Inverse of listAuthorizedResourceIds.

        Use Cases:
        - Resource access audit (who can access this?)
        - Team discovery for resources
        - Compliance and security audits

        Input: ListAuthorizedPrincipalIdsInput with resource, principal_kind, and relation
        Output: AuthorizedPrincipalIdsList containing all authorized principal IDs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IamPolicyQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.IamPolicyId.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2.IamPolicy.SerializeToString,
            ),
            'checkAuthorization': grpc.unary_unary_rpc_method_handler(
                    servicer.checkAuthorization,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationResult.SerializeToString,
            ),
            'listAuthorizedResourceIds': grpc.unary_unary_rpc_method_handler(
                    servicer.listAuthorizedResourceIds,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedResourceIdsInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedResourceIdsList.SerializeToString,
            ),
            'listAuthorizedPrincipalIds': grpc.unary_unary_rpc_method_handler(
                    servicer.listAuthorizedPrincipalIds,
                    request_deserializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedPrincipalIdsInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedPrincipalIdsList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IamPolicyQueryController(object):
    """iam-policy query controller
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/get',
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.IamPolicyId.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2.IamPolicy.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def checkAuthorization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/checkAuthorization',
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationInput.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.CheckAuthorizationResult.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def listAuthorizedResourceIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/listAuthorizedResourceIds',
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedResourceIdsInput.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedResourceIdsList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def listAuthorizedPrincipalIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.iam.iampolicy.v1.IamPolicyQueryController/listAuthorizedPrincipalIds',
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.ListAuthorizedPrincipalIdsInput.SerializeToString,
            ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2.AuthorizedPrincipalIdsList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/approval.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/approval.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ai/stigmer/agentic/agentexecution/v1/approval.proto\x12$ai.stigmer.agentic.agentexecution.v1\"\xd8\x02\n\x0fPendingApproval\x12 \n\x0ctool_call_id\x18\x01 \x01(\tR\ntoolCallId\x12\x1b\n\ttool_name\x18\x02 \x01(\tR\x08toolName\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12!\n\x0c\x61rgs_preview\x18\x04 \x01(\tR\x0b\x61rgsPreview\x12!\n\x0crequested_at\x18\x05 \x01(\tR\x0brequestedAt\x12$\n\x0e\x66rom_sub_agent\x18\x06 \x01(\x08R\x0c\x66romSubAgent\x12$\n\x0esub_agent_name\x18\x07 \x01(\tR\x0csubAgentName\x12\x37\n\x18\x63hild_agent_execution_id\x18\x08 \x01(\tR\x15\x63hildAgentExecutionId\x12!\n\x0cinterrupt_id\x18\t \x01(\tR\x0binterruptId\"\xa2\x01\n\x19\x43hildApprovalNotification\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x62\n\x11pending_approvals\x18\x02 \x03(\x0b\x32\x35.ai.stigmer.agentic.agentexecution.v1.PendingApprovalR\x10pendingApprovalsB\xee\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\rApprovalProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.approval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\rApprovalProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_PENDINGAPPROVAL']._serialized_start=94
  _globals['_PENDINGAPPROVAL']._serialized_end=438
  _globals['_CHILDAPPROVALNOTIFICATION']._serialized_start=441
  _globals['_CHILDAPPROVALNOTIFICATION']._serialized_end=603
# @@protoc_insertion_point(module_scope)



from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RunTaskConfig(_message.Message):
    __slots__ = ("workflow", "input")
    WORKFLOW_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    workflow: str
    input: _struct_pb2.Struct
    def __init__(self, workflow: _Optional[str] = ..., input: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/status.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import status_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_status__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/stigmer/agentic/skill/v1/status.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a+ai/stigmer/commons/apiresource/status.proto\x1a\x1b\x62uf/validate/validate.proto\"\xd3\x02\n\x0bSkillStatus\x12\x46\n\x05\x61udit\x18\x63 \x01(\x0b\x32\x30.ai.stigmer.commons.apiresource.ApiResourceAuditR\x05\x61udit\x12\x38\n\x0cversion_hash\x18\x01 \x01(\tB\x15\xbaH\x12r\x10\x32\x0e^[a-f0-9]{64}$R\x0bversionHash\x12\x30\n\x14\x61rtifact_storage_key\x18\x02 \x01(\tR\x12\x61rtifactStorageKey\x12=\n\x05state\x18\x03 \x01(\x0e\x32\'.ai.stigmer.agentic.skill.v1.SkillStateR\x05state\x12Q\n\x0egit_provenance\x18\x04 \x01(\x0b\x32*.ai.stigmer.agentic.skill.v1.GitProvenanceR\rgitProvenance\"\x82\x01\n\rGitProvenance\x12&\n\nremote_url\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\tremoteUrl\x12\x10\n\x03ref\x18\x02 \x01(\tR\x03ref\x12\x1f\n\x06\x63ommit\x18\x03 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x06\x63ommit\x12\x16\n\x06subdir\x18\x04 \x01(\tR\x06subdir*s\n\nSkillState\x12\x1b\n\x17SKILL_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15SKILL_STATE_UPLOADING\x10\x01\x12\x15\n\x11SKILL_STATE_READY\x10\x02\x12\x16\n\x12SKILL_STATE_FAILED\x10\x03\x42\xbf\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\x0bStatusProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\013StatusProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLSTATUS'].fields_by_name['version_hash']._loaded_options = None
  _globals['_SKILLSTATUS'].fields_by_name['version_hash']._serialized_options = b'\272H\022r\0202\016^[a-f0-9]{64}$'
  _globals['_GITPROVENANCE'].fields_by_name['remote_url']._loaded_options = None
  _globals['_GITPROVENANCE'].fields_by_name['remote_url']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GITPROVENANCE'].fields_by_name['commit']._loaded_options = None
  _globals['_GITPROVENANCE'].fields_by_name['commit']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_SKILLSTATE']._serialized_start=622
  _globals['_SKILLSTATE']._serialized_end=737
  _globals['_SKILLSTATUS']._serialized_start=148
  _globals['_SKILLSTATUS']._serialized_end=487
  _globals['_GITPROVENANCE']._serialized_start=490
  _globals['_GITPROVENANCE']._serialized_end=620
# @@protoc_insertion_point(module_scope)



import datetime

from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Duration(_message.Message):
    __slots__ = ("days", "hours", "minutes", "seconds", "milliseconds")
    DAYS_FIELD_NUMBER: _ClassVar[int]
    HOURS_FIELD_NUMBER: _ClassVar[int]
    MINUTES_FIELD_NUMBER: _ClassVar[int]
    SECONDS_FIELD_NUMBER: _ClassVar[int]
    MILLISECONDS_FIELD_NUMBER: _ClassVar[int]
    days: int
    hours: int
    minutes: int
    seconds: int
    milliseconds: int
    def __init__(self, days: _Optional[int] = ..., hours: _Optional[int] = ..., minutes: _Optional[int] = ..., seconds: _Optional[int] = ..., milliseconds: _Optional[int] = ...) -> None: ...

class WaitTaskConfig(_message.Message):
    __slots__ = ("duration", "until")
    DURATION_FIELD_NUMBER: _ClassVar[int]
    UNTIL_FIELD_NUMBER: _ClassVar[int]
    duration: Duration
    until: _timestamp_pb2.Timestamp
    def __init__(self, duration: _Optional[_Union[Duration, _Mapping]] = ..., until: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class WorkflowInstanceQueryControllerStub(object):
    """WorkflowInstanceQueryController handles read operations (Get, List, Search) for WorkflowInstance resources.

    This service provides all query operations following the Command-Query Separation pattern.
    All RPCs that read state without modifying it go through this controller.

    Authorization:
    - get: Requires get permission on the specific instance
    - getByWorkflow: Authorization handled in handler via FGA query (returns filtered instances)
    - getByReference: Custom authorization (supports flexible reference lookup)

    All operations respect owner scope visibility rules (users see only their org/identity resources).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/get',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.FromString,
                _registered_method=True)
        self.getByWorkflow = channel.unary_unary(
                '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/getByWorkflow',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.GetWorkflowInstancesByWorkflowRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceList.FromString,
                _registered_method=True)
        self.getByReference = channel.unary_unary(
                '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/getByReference',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.FromString,
                _registered_method=True)


class WorkflowInstanceQueryControllerServicer(object):
    """WorkflowInstanceQueryController handles read operations (Get, List, Search) for WorkflowInstance resources.

    This service provides all query operations following the Command-Query Separation pattern.
    All RPCs that read state without modifying it go through this controller.

    Authorization:
    - get: Requires get permission on the specific instance
    - getByWorkflow: Authorization handled in handler via FGA query (returns filtered instances)
    - getByReference: Custom authorization (supports flexible reference lookup)

    All operations respect owner scope visibility rules (users see only their org/identity resources).
    """

    def get(self, request, context):
        """Get a single workflow instance by ID.

        Retrieves a specific WorkflowInstance using its unique resource identifier.

        Input:
        WorkflowInstanceId with the instance ID (e.g., "wfi-abc123")

        Returns:
        Complete WorkflowInstance resource with:
        - api_version, kind, metadata
        - spec (workflow_id, description, environment_refs)
        - status (audit information: created_at, updated_at, version)

        Authorization:
        Requires "get" permission on the specific WorkflowInstance.
        Field path "value" extracts the resource ID from WorkflowInstanceId wrapper.
        Verifies user has access based on:
        - Instance owner scope (organization or identity_account)
        - User's IAM policies

        Use Cases:
        - Retrieve instance configuration before executing
        - View instance details in UI
        - Fetch instance for editing/updating

        Error: PERMISSION_DENIED if user lacks get permission
        Error: NOT_FOUND if instance ID doesn't exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getByWorkflow(self, request, context):
        """Get all instances of a specific workflow template.

        Retrieves all WorkflowInstance resources that reference a specific Workflow template.
        Useful for discovering all configured deployments of a workflow.

        Example Use Case:
        Workflow "deploy-to-cloud" (wfl-123) has instances:
        - "prod-deploy" (wfi-abc) - Production deployment with aws-prod-env
        - "staging-deploy" (wfi-def) - Staging deployment with aws-staging-env
        - "dev-deploy" (wfi-ghi) - Development deployment with aws-dev-env

        Input:
        GetWorkflowInstancesByWorkflowRequest with:
        - workflow_id: Workflow template ID to filter by
        - page_info: Pagination settings (page_size, page_token)

        Returns:
        WorkflowInstanceList with:
        - total_pages: Total number of pages available
        - entries: Array of WorkflowInstance resources in current page

        Authorization:
        Authorization is handled in handler via FGA query for authorized workflow_instance_ids,
        then filtered by workflow_id. This ensures users only see instances they have access to,
        even if the parent workflow is shared across organizations.

        Filtering:
        Results are filtered by:
        - User's organization/identity visibility
        - IAM policies
        - Owner scope rules

        Error: PERMISSION_DENIED if user lacks access to the workflow
        Error: NOT_FOUND if workflow_id doesn't exist
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getByReference(self, request, context):
        """Get a workflow instance by flexible reference (ID or slug).

        Retrieves a WorkflowInstance using ApiResourceReference which supports multiple lookup methods:
        - By ID: {id: "wfi-abc123"}
        - By slug: {slug: "prod-deploy"}
        - By name: {name: "Production Deploy"}

        Input:
        ApiResourceReference with one of: id, slug, or name

        Returns:
        Complete WorkflowInstance resource matching the reference.

        Authorization:
        Uses custom authorization logic in the handler.
        Allows for flexible authorization based on reference type and context.
        Typical checks:
        - User has get permission on the resolved instance
        - Instance owner scope matches user's organization/identity

        Use Cases:
        - User-friendly lookups by slug instead of opaque IDs
        - CLI commands using human-readable names
        - API integrations using stable slugs

        Example:
        Input: ApiResourceReference{slug: "prod-deploy"}
        Output: WorkflowInstance with metadata.slug = "prod-deploy"

        Error: PERMISSION_DENIED if user lacks access
        Error: NOT_FOUND if reference doesn't resolve to an instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowInstanceQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.SerializeToString,
            ),
            'getByWorkflow': grpc.unary_unary_rpc_method_handler(
                    servicer.getByWorkflow,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.GetWorkflowInstancesByWorkflowRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceList.SerializeToString,
            ),
            'getByReference': grpc.unary_unary_rpc_method_handler(
                    servicer.getByReference,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkflowInstanceQueryController(object):
    """WorkflowInstanceQueryController handles read operations (Get, List, Search) for WorkflowInstance resources.

    This service provides all query operations following the Command-Query Separation pattern.
    All RPCs that read state without modifying it go through this controller.

    Authorization:
    - get: Requires get permission on the specific instance
    - getByWorkflow: Authorization handled in handler via FGA query (returns filtered instances)
    - getByReference: Custom authorization (supports flexible reference lookup)

    All operations respect owner scope visibility rules (users see only their org/identity resources).
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/get',
            ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getByWorkflow(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/getByWorkflow',
            ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.GetWorkflowInstancesByWorkflowRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2.WorkflowInstanceList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getByReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceQueryController/getByReference',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceReference.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2.WorkflowInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflowinstance/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflowinstance/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflowinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflowinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflowinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ai/stigmer/agentic/workflowinstance/v1/command.proto\x12&ai.stigmer.agentic.workflowinstance.v1\x1a\x30\x61i/stigmer/agentic/workflowinstance/v1/api.proto\x1a/ai/stigmer/agentic/workflowinstance/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xa7\x05\n!WorkflowInstanceCommandController\x12{\n\x05\x61pply\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x12\x82\x01\n\x06\x63reate\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"\x04\xd0\xb8\x18\x01\x12\xbd\x01\n\x06update\x12\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"?\xc2\xb8\x18;\x08\x04\x10\x33\"\x0bmetadata.id*(unauthorized to update workflow instance\x12\xb9\x01\n\x06\x64\x65lete\x12:.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstanceId\x1a\x38.ai.stigmer.agentic.workflowinstance.v1.WorkflowInstance\"9\xc2\xb8\x18\x35\x08\x02\x10\x33\"\x05value*(unauthorized to delete workflow instance\x1a\x04\xa0\xff+3B\xf7\x01\n*com.ai.stigmer.agentic.workflowinstance.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02&Ai.Stigmer.Agentic.Workflowinstance.V1\xca\x02&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\xe2\x02\x32\x41i\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\xea\x02*Ai::Stigmer::Agentic::Workflowinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflowinstance.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.ai.stigmer.agentic.workflowinstance.v1B\014CommandProtoP\001\242\002\004ASAW\252\002&Ai.Stigmer.Agentic.Workflowinstance.V1\312\002&Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\342\0022Ai\\Stigmer\\Agentic\\Workflowinstance\\V1\\GPBMetadata\352\002*Ai::Stigmer::Agentic::Workflowinstance::V1'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_options = b'\240\377+3'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\320\270\030\001'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\030;\010\004\0203\"\013metadata.id*(unauthorized to update workflow instance'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\0305\010\002\0203\"\005value*(unauthorized to delete workflow instance'
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_start=321
  _globals['_WORKFLOWINSTANCECOMMANDCONTROLLER']._serialized_end=1000
# @@protoc_insertion_point(module_scope)
